function _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceTarget(p) {
}
function _aws_cdk_aws_elasticloadbalancingv2_targets_AlbTarget(p) {
}
function _aws_cdk_aws_elasticloadbalancingv2_targets_AlbArnTarget(p) {
}
function _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceIdTarget(p) {
}
function _aws_cdk_aws_elasticloadbalancingv2_targets_IpTarget(p) {
}
function _aws_cdk_aws_elasticloadbalancingv2_targets_LambdaTarget(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_AlbTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_AlbArnTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_InstanceIdTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_IpTarget, _aws_cdk_aws_elasticloadbalancingv2_targets_LambdaTarget };
module.exports.DeprecationError = DeprecationError;
